@@ -4,7 +4,6 @@ use 5.006;
 use strict;
 use warnings;
 use File::Slurp;
-use TOML::Tiny qw(to_toml);
 use base 'Ixchel::Actions::base';
 use Sys::Hostname;
 
@@ -14,11 +13,11 @@ Ixchel::Actions::lilith_config - Generates the config for Lilith.
 
 =head1 VERSION
 
-Version 0.1.0
+Version 0.2.0
 
 =cut
 
-our $VERSION = '0.1.0';
+our $VERSION = '0.2.0';
 
 =head1 CLI SYNOPSIS
 
@@ -214,10 +213,11 @@ sub action_extra {
 		} ## end elsif ( $self->{config}{sagan}{enable} && $self...)
 	} ## end if ( $self->{config}{lilith}{auto_config}{...})
 
-	my $toml = to_toml($config);
-	eval { };
+	my $toml;
+	my $to_eval = 'use TOML::Tiny qw(to_toml); $toml = to_toml($config);';
+	eval $to_eval;
 	if ($@) {
-		$self->status_add( error => 1, status => 'Errored generating TOML for config ... ' . $@ );
+		$self->status_add( error => 1, status => 'Errored generating TOML for config... Is TOML::Tiny installed? cpanm TOML::Tiny ?... ' . $@ );
 		return undef;
 	}
 
